@@ -7,7 +7,7 @@ use Perl::Review::Violation;
 use base 'Perl::Review::Policy';
 
 use vars qw($VERSION);
-$VERSION = '0.03';
+$VERSION = '0.04';
 
 sub violations {
     my ($self, $doc) = @_;
@@ -38,7 +38,7 @@ give them clear names.
   $| = undef;                      #not ok
 
   use English qw(-no_match_vars);
-  local $AUTOFLUSH = undef;        #ok
+  local $OUTPUT_AUTOFLUSH = undef;        #ok
 
 =head1 NOTES
 
